@@ -61,7 +61,7 @@ class QATrainArguments:
         metadata={"help": "monitor condition (save top k)"}
     )
     seed: int = field(
-        default=7,
+        default=None,
         metadata={"help": "random seed."}
     )
     overwrite_cache: bool = field(
